# mypy-boto3-guardduty

[![PyPI - mypy-boto3](https://img.shields.io/pypi/v/mypy-boto3.svg?color=blue&style=for-the-badge)](https://pypi.org/project/mypy-boto3)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3.svg?color=blue&style=for-the-badge)](https://pypi.org/project/mypy-boto3)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3.svg?color=blue&style=for-the-badge)](https://mypy-boto3.readthedocs.io/)
[![Coverage](https://img.shields.io/codecov/c/github/vemel/mypy_boto3?style=for-the-badge)](https://codecov.io/gh/vemel/mypy_boto3)

Type annotations for
[boto3.GuardDuty 1.11.7](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/guardduty.html#GuardDuty) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

More information can be found [here](https://vemel.github.io/mypy_boto3/).

- [mypy-boto3-guardduty](#mypy-boto3-guardduty)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `GuardDuty` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-guardduty]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import guardduty
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_guardduty as guardduty

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("guardduty")
client: guardduty.GuardDutyClient = boto3.client("guardduty")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: guardduty.GuardDutyClient = session.client("guardduty")


# Paginators need type annotation on creation
list_detectors_paginator: guardduty.ListDetectorsPaginator = client.get_paginator("list_detectors")
list_filters_paginator: guardduty.ListFiltersPaginator = client.get_paginator("list_filters")
list_findings_paginator: guardduty.ListFindingsPaginator = client.get_paginator("list_findings")
list_ip_sets_paginator: guardduty.ListIPSetsPaginator = client.get_paginator("list_ip_sets")
list_invitations_paginator: guardduty.ListInvitationsPaginator = client.get_paginator("list_invitations")
list_members_paginator: guardduty.ListMembersPaginator = client.get_paginator("list_members")
list_threat_intel_sets_paginator: guardduty.ListThreatIntelSetsPaginator = client.get_paginator("list_threat_intel_sets")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.